clc; 
clear all
close all 

global V_wind Rho Wing_surface Mean_chord l_4 l_3 Cl_alpha Cl_zero Cm_alpha ...
        Cm_zero Cd_zero K_cd Mass
    
%% INPUT VAR

Mass = 2.35; %[Kg] Mass of the vehicle
V_wind = 5; %[m/s] Wind speed     
Rho = 1.22; %[kg/m^3] Air density
Wing_surface = 0.57; %[m^2] Wing surface
Mean_chord = 0.3325; %[m] Average wing chord
l_4 = 0.29; %[m] x-axis offset of the front motors
l_3 = 0.36; %[m] x-axis offset of the back motors
Cl_alpha = 4.2; %[1/rad] Cl rate in 1/rad
Cl_zero = -0.05; % Cl at alpha equal to zero
Cm_alpha = -0.58; %[1/rad] Cm rate in 1/rad
Cm_zero = .002; % Cm at alpha equal to zero
Cd_zero = 0.5; % Cd at alpha equal to zero
K_cd = 0.08; %Quadratic therm of drag
M_q = -3.5; %Coefficient for torque vs q

%Actuator properties:
Max_thrust = 8.8; %[N] Maximum thrust value
k_t = 0.95*10^-5; %Coefficient of thrust for the motor
Azimuth_cut_freq = 30.7; %[rad/s] Cutting frequency of the first order azimuth tilting dynamics
Elevation_cut_freq = 26.16; %[rad/s] Cutting frequency of the first order elevation tilting dynamics
Servo_delay_Ts = 10;%[mS] Delay of the servomotor activating the tilting mechanism
Motor_cut_freq = 19.35; %[rad/s] Cutting frequency of the first order motor dynamics
Motor_delay_Ts = 15;%[mS] Delay of the motor
I_yy = 0.1; %[kg*m^2] Intertia of the vehicle in the pitch axes

%% Script

%Calculation of the omega equilibrium
fun = @system_equation_quadplane_conventional;
x0 = [Mass*9.81/4,Mass*9.81/4,Mass*9.81/4,Mass*9.81/4,-1];
V_wind_solved = V_wind;
V_wind = 0;
x = fsolve(fun,x0);

Omega_eq = sqrt(x(1:4)/k_t);
Thrust_eq = x(1:4);

max_omega_motor = sqrt(Max_thrust/k_t); 

%Conventional platform 
V_wind = V_wind_solved;
fun = @system_equation_quadplane_conventional;
x0 = [Mass*9.81/4,Mass*9.81/4,Mass*9.81/4,Mass*9.81/4,-1];
x = fsolve(fun,x0);
theta_eq = x(5);
Omega_wind = sqrt(x(1:4)/k_t);
Thrust_wind = x(1:4);

i = 1;
V_wind = 1;
while(max(x) <= Max_thrust)
    V_wind = V_wind + 0.01;
    x = fsolve(fun,x0);
    Wind_test_conventional(i) = V_wind;
    Theta_eq_conventional(i) = x(5)*180/pi;
    i = i+1;
end
critical_wind_conventional = V_wind;
critical_theta_conventional = x(5)*180/pi;

%Overactuated platform 
V_wind = V_wind_solved;
fun = @system_equation_quadplane_overactuated;
x0 = [Mass*9.81/4,Mass*9.81/4,Mass*9.81/4,Mass*9.81/4,-1];
x = fsolve(fun,x0);

Omega_wind_over = sqrt(x(1:4)/k_t);
b_eq = x(5);

i = 1;
V_wind = 1;
while(max(x) <= Max_thrust || b_eq >= pi)
    V_wind = V_wind + 0.01;
    x = fsolve(fun,x0);
    Wind_test_overactuated(i) = V_wind;
    el_angle_eq_overactuated(i) = x(5)*180/pi;
    i = i+1;
end
critical_wind_overactuated = V_wind;
critical_el_angle_conventional = x(5)*180/pi;

% plot the curve: 
figure()
plot(Theta_eq_conventional,Wind_test_conventional,'r');
hold on 
plot(el_angle_eq_overactuated,Wind_test_overactuated,'b');
plot(critical_theta_conventional,critical_wind_conventional,'xr');
plot(critical_el_angle_conventional,critical_wind_overactuated,'xb');
legend('Theta angle conventional quadplane','Elevation tilting angle overactuated quadplane')
xlabel('Angle [deg]');
ylabel('Wind speed [m/s]');
set ( gca, 'xdir', 'reverse' )

%display results
fprintf('\n                 ** EQUILIBRIUM ROTATIONAL SPEED ROTORS WITH ZERO WIND **')

omega_equilibrium_display = append('\n\n Omega equilibrium without wind motor 1 to 4 = ',num2str(Omega_eq(1)),' ; ',num2str(Omega_eq(2)),' ; ',num2str(Omega_eq(3)),' ; ',num2str(Omega_eq(4)),' [rad/s] \n');
fprintf(omega_equilibrium_display)

omega_equilibrium_wind_display = append('\n Omega equilibrium with wind motor 1 to 4 = ',num2str(Omega_wind(1)),' ; ',num2str(Omega_wind(2)),' ; ',num2str(Omega_wind(3)),' ; ',num2str(Omega_wind(4)),' [rad/s] \n');
fprintf(omega_equilibrium_wind_display)

fprintf('\n                 ** RESULTS FOR CONVENTIONAL PLATFORM **')

theta_equilibrium_display_conventional = append('\n \n Theta equilibrium value at ',num2str(V_wind_solved),' m/s = ',num2str(theta_eq*180/pi),' [deg] \n');
fprintf(theta_equilibrium_display_conventional)

max_wind_display_conventional = append('\n Maximum allowable wind speed = ',num2str(critical_wind_conventional),' m/s \n');
fprintf(max_wind_display_conventional)

critical_theta_display_conventional = append('\n Critical theta value at ',num2str(critical_wind_conventional),' m/s = ',num2str(critical_theta_conventional),' [deg] \n');
fprintf(critical_theta_display_conventional)

fprintf('\n                 ** RESULTS FOR OVERACTUATED PLATFORM **')

b_equilibrium_display_overactuated = append('\n \n Elevation angle equilibrium value at ',num2str(V_wind_solved),' m/s = ',num2str(b_eq*180/pi),' [deg] \n');
fprintf(b_equilibrium_display_overactuated)

max_wind_display_conventional = append('\n Maximum allowable wind speed = ',num2str(V_wind),' m/s \n');
fprintf(max_wind_display_conventional)
critical_b_display_conventional = append('\n Critical elevation angle value at ',num2str(V_wind),' m/s = ',num2str(critical_el_angle_conventional),' [deg] \n');
fprintf(critical_b_display_conventional)
